CustomTextFieldWidget class

A customizable text field widget with extensive styling options.

This widget provides a flexible text input field with support for custom styling, validation, input formatting, and various input types. It's used internally by the date picker but can also be used standalone.

Inheritance

Constructors

CustomTextFieldWidget({Key? key, String? initialValue, String? label, String? hintText, Widget? prefix, Widget? suffix, VoidCallback? suffixAction, TextEditingController? controller, TextInputType? inputType, TextCapitalization textCapitalization = TextCapitalization.none, FormFieldValidator? validator, bool obscureText = false, bool? isEnabled = true, Color? color = const Color(0xFF3E4A59), void onChanged(String)?, double? fontSize, bool centerText = false, bool readOnly = false, String? errorMessage, void onSubmitted(String)?, bool? filled = false, Color? fillColor, List<TextInputFormatter>? inputFormatters, TextStyle? hintStyle, TextStyle? textStyle, TextStyle? labelTextStyle, EdgeInsets? contentPadding, int? maxLength, VoidCallback? onTap, InputBorder? border, TextInputAction? textInputAction, FocusNode? focusNode, AutovalidateMode autovalidateMode = AutovalidateMode.onUserInteraction, bool unFocusOnTapOutside = false})
Creates a CustomTextFieldWidget with the specified parameters.

Properties

autovalidateMode AutovalidateMode
final
border InputBorder?
final
centerText bool
getter/setter pair
color Color?
final
contentPadding EdgeInsets?
final
controller TextEditingController?
final
errorMessage String?
final
fillColor Color?
final
filled bool?
final
focusNode FocusNode?
final
fontSize double?
final
hashCode int
The hash code for this object.
no setterinherited
hintStyle TextStyle?
final
hintText String?
final
initialValue String?
final
inputFormatters List<TextInputFormatter>?
final
inputType TextInputType?
final
isEnabled bool?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
final
labelTextStyle TextStyle?
final
maxLength int?
final
obscureText bool
getter/setter pair
onChanged → void Function(String)?
final
onSubmitted → void Function(String)?
final
onTap VoidCallback?
final
prefix Widget?
final
readOnly bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffix Widget?
final
suffixAction VoidCallback?
final
textCapitalization TextCapitalization
final
textInputAction TextInputAction?
final
textStyle TextStyle?
final
unFocusOnTapOutside bool
final
validator FormFieldValidator?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _CustomTextFieldWidgetState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited