CalendarBottomSheet class

Utility class for showing calendar bottom sheets programmatically.

This class provides static methods to display date picker and month/year picker bottom sheets without needing to use the CustomDateSelector widget.

Constructors

CalendarBottomSheet()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

showDatePicker(BuildContext context, {required void onDateSelected(int year, int month, int day), String? title, int? maxYear, String? type, CalendarTheme? theme, String? buttonText, Widget? customButton}) Future<void>
Shows a date picker bottom sheet that can be called from anywhere.
showMonthYearPicker(BuildContext context, {required void onDateSelected(int year, int month, int day), String? title, int? maxYear, String? type, CalendarTheme? theme, String? buttonText, Widget? customButton}) Future<void>
Shows a month/year picker bottom sheet (without day selection).