CalendarTheme constructor

const CalendarTheme({
  1. Color backgroundColor = Colors.white,
  2. Color primaryColor = Colors.black,
  3. Color textColor = Colors.black87,
  4. Color selectedColor = Colors.blue,
  5. Color dividerColor = Colors.grey,
  6. Color buttonColor = Colors.black,
  7. Color buttonTextColor = Colors.white,
  8. Color titleColor = Colors.black87,
  9. Color handleColor = Colors.grey,
})

Creates a custom calendar theme with the specified colors.

All parameters are optional and will use default values if not provided.

Implementation

const CalendarTheme({
  this.backgroundColor = Colors.white,
  this.primaryColor = Colors.black,
  this.textColor = Colors.black87,
  this.selectedColor = Colors.blue,
  this.dividerColor = Colors.grey,
  this.buttonColor = Colors.black,
  this.buttonTextColor = Colors.white,
  this.titleColor = Colors.black87,
  this.handleColor = Colors.grey,
});