custom_textform library

Classes

CustomPasswordTextFieldWidget
A specialized text field widget for password input with show/hide toggle.
CustomTextFieldWidget
A customizable text field widget with extensive styling options.