CalendarTheme constructor
const
CalendarTheme({
- Color backgroundColor = Colors.white,
- Color primaryColor = Colors.black,
- Color textColor = Colors.black87,
- Color selectedColor = Colors.blue,
- Color dividerColor = Colors.grey,
- Color buttonColor = Colors.black,
- Color buttonTextColor = Colors.white,
- Color titleColor = Colors.black87,
- Color handleColor = Colors.grey,
Creates a custom calendar theme with the specified colors.
All parameters are optional and will use default values if not provided.
Implementation
const CalendarTheme({
this.backgroundColor = Colors.white,
this.primaryColor = Colors.black,
this.textColor = Colors.black87,
this.selectedColor = Colors.blue,
this.dividerColor = Colors.grey,
this.buttonColor = Colors.black,
this.buttonTextColor = Colors.white,
this.titleColor = Colors.black87,
this.handleColor = Colors.grey,
});